import { jsxs, jsx } from '@emotion/react/jsx-runtime';
import { Box, Text, InputGroup, Input, InputRightElement, Spinner, IconButton, Icon } from '@chakra-ui/react';
import { defineComponent } from '@qorebase/app-component';
import React from 'react';
import { TargetLock } from '@feedloop/icon';

const TextInput = defineComponent({
    name: "Location Input",
    type: "none",
    icon: "LocationInput",
    group: "input",
    display: "inline",
    defaultProps: {
        label: "Location Input",
        hidden: false,
        placeholder: "Placeholder here",
        data: {
            inputID: "location",
            field: { type: "string", options: { format: "text" } },
            validation: {
                required: false,
            },
        },
        defaultValue: "",
    },
    propDefinition: {
        label: { group: "Design", type: "expression", options: {} },
        placeholder: {
            group: "Design",
            type: "expression",
            options: {},
        },
        hidden: { group: "Design", type: "boolean", options: {} },
        data: {
            group: "Design",
            type: "state",
            options: {
                inputID: "location",
                field: { type: "string", options: { format: "text" } },
            },
        },
        defaultValue: {
            group: "Design",
            type: "expression",
            options: {},
        },
    },
    Component: (props) => {
        const title = props.hooks.useEvaluate(props.properties.label);
        const placeholder = props.hooks.useEvaluate(props.properties.placeholder);
        const defaultValue = props.hooks.useEvaluate(props.properties.defaultValue);
        const data = props.hooks.useRuntimeInput(props.properties.data, props.data.page.row, {
            defaultValue,
            validate: (value) => {
                if (!value) {
                    return { error: "Required field, Please enter the data" };
                }
            },
        });
        const handleChange = React.useCallback((e) => {
            data.onChange(e.currentTarget.value);
        }, [data.onChange]);
        const [supported, setSupported] = React.useState(true);
        const [locating, setLocating] = React.useState(true);
        const getLocation = () => {
            if (navigator.geolocation) {
                setLocating(true);
                navigator.geolocation.getCurrentPosition((position) => {
                    data.onChange(`${position.coords.latitude},${position.coords.longitude}`);
                    setLocating(false);
                });
            }
            else {
                setLocating(false);
                setSupported(false);
            }
        };
        React.useEffect(() => {
            getLocation();
        }, []);
        return (jsxs(Box, Object.assign({ display: props.properties.hidden ? "none" : undefined }, { children: [jsx(Text, Object.assign({ fontSize: "lg", pb: 2, "data-test": "location-input-title" }, { children: title })), jsxs(InputGroup, Object.assign({ size: "md" }, { children: [jsx(Input, { pr: "10", style: { border: "1px solid rgb(226, 232, 240)" }, bgColor: "surface.900", placeholder: placeholder, name: props.properties.data.inputID, defaultValue: data.value, onChange: handleChange, disabled: supported, _disabled: { border: "1px solid rgb(226, 232, 240)" }, "data-test": "location-input" }, props.properties.data.inputID), jsx(InputRightElement, Object.assign({ width: "10" }, { children: locating ? (jsx(Spinner, {})) : (jsx(IconButton, { "aria-label": "locate", variant: "link", icon: jsx(Icon, { as: TargetLock }), onClick: getLocation, "data-test": "location-input-toggle" })) }))] })), !!data.validation.error && (jsx(Text, Object.assign({ fontSize: "sm", color: "red", "data-test": "location-input-error" }, { children: data.validation.error })))] })));
    },
});

export { TextInput as default };
